#include "qerrormessage.h"

QErrorMessage::QErrorMessage()
    :QObject(0)
{

}

QErrorMessage::QErrorMessage(QString code, QString text)
{
    this->code = code;
    this->text = text;
}

QErrorMessage::QErrorMessage(const QErrorMessage & src)
    :QObject(src.parent())
{
    QErrorMessage::copyData(this, &src);
}

void QErrorMessage::copyData(QErrorMessage *dst, const QErrorMessage *src)
{
    dst->code = src->code;
    dst->text = src->text;
    dst->comment = src->comment;
}
